==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/FunctionFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { FunctionFilterExpressionDescription } from "./FunctionFilterExpressionDescription";
/**
 * @hidden
 */
var FunctionFilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunctionFilterExpressionDescriptionMetadata, _super);
    function FunctionFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunctionFilterExpressionDescriptionMetadata.b = function (a) {
        if (FunctionFilterExpressionDescriptionMetadata.a == null) {
            FunctionFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunctionFilterExpressionDescriptionMetadata.c(FunctionFilterExpressionDescriptionMetadata.a);
        }
        if (a.g(FunctionFilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.s(FunctionFilterExpressionDescriptionMetadata.a);
    };
    FunctionFilterExpressionDescriptionMetadata.c = function (a) {
        FilterExpressionDescriptionMetadata.c(a);
        a.item("FunctionType", "ExportedType:string:FilterExpressionFunctionType");
        a.item("FunctionType@names", "Contains;EndsWith;StartsWith;Length;IndexOf;Replace;Substring;ToLower;ToUpper;Trim;Concat;Day;Hour;Minute;Month;Second;Year;Round;Floor;Ceiling;Date;Time;Now;IsOf;Cast");
        a.item("FunctionArguments", "Collection:FilterExpression:FilterExpressionCollection:FilterExpression");
    };
    FunctionFilterExpressionDescriptionMetadata.d = function (a) {
        FunctionFilterExpressionDescriptionMetadata.b(a);
        a.u("FunctionFilterExpression", function () { return new FunctionFilterExpressionDescription(); });
        a.t("FunctionFilterExpression", FunctionFilterExpressionDescriptionMetadata.a);
    };
    FunctionFilterExpressionDescriptionMetadata.$t = markType(FunctionFilterExpressionDescriptionMetadata, 'FunctionFilterExpressionDescriptionMetadata');
    FunctionFilterExpressionDescriptionMetadata.a = null;
    return FunctionFilterExpressionDescriptionMetadata;
}(Base));
export { FunctionFilterExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FunctionFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { FunctionFilterExpressionDescription } from "./FunctionFilterExpressionDescription";
/**
 * @hidden
 */
var FunctionFilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunctionFilterExpressionDescriptionMetadata, _super);
    function FunctionFilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunctionFilterExpressionDescriptionMetadata.b = function (a) {
        if (FunctionFilterExpressionDescriptionMetadata.a == null) {
            FunctionFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunctionFilterExpressionDescriptionMetadata.c(FunctionFilterExpressionDescriptionMetadata.a);
        }
        if (a.j(FunctionFilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(FunctionFilterExpressionDescriptionMetadata.a);
    };
    FunctionFilterExpressionDescriptionMetadata.c = function (a) {
        FilterExpressionDescriptionMetadata.c(a);
        a.item("FunctionType", "ExportedType:string:FilterExpressionFunctionType");
        a.item("FunctionType@names", "Contains;EndsWith;StartsWith;Length;IndexOf;Replace;Substring;ToLower;ToUpper;Trim;Concat;Day;Hour;Minute;Month;Second;Year;Round;Floor;Ceiling;Date;Time;Now;IsOf;Cast");
        a.item("FunctionArguments", "Collection:FilterExpression:FilterExpressionCollection:FilterExpression");
    };
    FunctionFilterExpressionDescriptionMetadata.d = function (a) {
        FunctionFilterExpressionDescriptionMetadata.b(a);
        a.aa("FunctionFilterExpression", function () { return new FunctionFilterExpressionDescription(); });
        a.z("FunctionFilterExpression", FunctionFilterExpressionDescriptionMetadata.a);
    };
    FunctionFilterExpressionDescriptionMetadata.$t = markType(FunctionFilterExpressionDescriptionMetadata, 'FunctionFilterExpressionDescriptionMetadata');
    FunctionFilterExpressionDescriptionMetadata.a = null;
    return FunctionFilterExpressionDescriptionMetadata;
}(Base));
export { FunctionFilterExpressionDescriptionMetadata };
